@@ -21,6 +21,8 @@
 #include "knewstuff_export.h"
 #include "entry.h"
 
+#if KNEWSTUFF_ENABLE_DEPRECATED_SINCE(5, 29)
+
 namespace KNS3
 {
 class DownloadManagerPrivate;
@@ -30,6 +32,7 @@ class DownloadManagerPrivate;
  * without using the widgets and to look for updates of
  * already installed items without showing the dialog.
  * @since 4.5
+ * @deprecated Since 5.29, use KNSCore::DownloadManager instead
  */
 class KNEWSTUFF_EXPORT DownloadManager : public QObject
 {
@@ -49,16 +52,20 @@ public:
      * Appname is the name of your application as provided in the about data->
      *
      * @param parent the parent of the dialog
+     * @deprecated Since 5.29, use KNSCore::DownloadManager instead
      */
-    explicit DownloadManager(QObject *parent = 0);
+    KNEWSTUFF_DEPRECATED_VERSION(5, 29, "Use KNSCore::DownloadManager")
+    explicit DownloadManager(QObject *parent = nullptr);
 
     /**
      * Create a DownloadManager. Manually specifying the name of the .knsrc file.
      *
      * @param configFile the name of the configuration file
      * @param parent
+     * @deprecated Since 5.29, use KNSCore::DownloadManager instead
      */
-    explicit DownloadManager(const QString &configFile, QObject *parent = 0);
+    KNEWSTUFF_DEPRECATED_VERSION(5, 29, "Use KNSCore::DownloadManager")
+    explicit DownloadManager(const QString &configFile, QObject *parent = nullptr);
 
     /**
      * destructor
@@ -76,6 +83,14 @@ public:
       */
     void checkForUpdates();
 
+    /**
+      Check for installed resources
+      Use searchResult to get notified about installed entries.
+
+      @since 5.28
+      */
+    void checkForInstalled();
+
     /**
       Installs or updates an entry
       @param entry
@@ -104,6 +119,15 @@ public:
       */
     void setSearchOrder(SortOrder order);
 
+    /**
+     * Triggers a search for an entry with @p id as its unique id
+     *
+     * @see searchResult
+     *
+     * @since 5.28
+     */
+    void fetchEntryById(const QString &id);
+
 Q_SIGNALS:
     /**
       Returns the search result.
@@ -127,12 +151,14 @@ Q_SIGNALS:
 private:
     Q_PRIVATE_SLOT(d, void _k_slotProvidersLoaded())
     Q_PRIVATE_SLOT(d, void _k_slotEngineError(const QString &error))
-    Q_PRIVATE_SLOT(d, void _k_slotEntryStatusChanged(const KNS3::EntryInternal &entry))
-    Q_PRIVATE_SLOT(d, void _k_slotEntriesLoaded(const KNS3::EntryInternal::List &entries))
-    DownloadManagerPrivate *const d;
+    Q_PRIVATE_SLOT(d, void _k_slotEntryStatusChanged(const KNSCore::EntryInternal &entry))
+    Q_PRIVATE_SLOT(d, void _k_slotEntriesLoaded(const KNSCore::EntryInternal::List &entries))
+    KNS3::DownloadManagerPrivate *const d;
     Q_DISABLE_COPY(DownloadManager)
 };
 
 }
 
+#endif // KNEWSTUFF_ENABLE_DEPRECATED_SINCE(5, 29)
+
 #endif
